pyql-weather
============

Wrapper escrito en Python para realizar consultar YQL y obtener información de los servidores de Yahoo.

Instalación.
-------------

La manera fácil de instalar la librería es a través de la herramienta pip::

    pip install pyql-weather

o de igual manera se puede descargar el archivo tar.gz desde:

1. https://pypi.python.org/pypi/pyql-weather/0.2

y ejecutar el siguiente comando::

    python setup.py install


Acceso a tablas
---------------

Se tiene disponible el acceso a las siguientes tablas:


* geo.continents
* geo.counties
* geo.countries
* geo.seas
* geo.placetypes
* geo.placefinder
* geo.places
* geo.concordance
* geo.states
* geo.oceans
* geo.districs
* weather.forecast

Otras Características:
######################

Adicional a estas tablas, existe un objeto llamado:

   + YQLConnector

El cual nos permite ejecutar consultas YQL personalizadas a Yahoo.


Documentación
-------------

Si deseas leer más sobre esta librería, te recomiendo ingresar a:

* http://pyql-weather.readthedocs.org


Autor:
=======

Alex Dzul

* Python & Django Developer.


1. http://alexdzul.com
2. http://github.com/alexdzul
3. http://twitter.com/alexjs88